@@ -1,7 +1,7 @@
 package CPAN::Reporter;
 use strict;
 use vars qw/$VERSION/;
-$VERSION = '1.07_06'; 
+$VERSION = '1.14_01'; 
 $VERSION = eval $VERSION;
 
 use Config;
@@ -95,12 +95,14 @@ sub record_command {
 
     # XXX refactor this! 
     # Get configuration options
-    my $config_obj = CPAN::Reporter::Config::_open_config_file();
-    my $config;
-    $config = CPAN::Reporter::Config::_get_config_options( $config_obj ) 
-        if $config_obj;
+    if ( -r CPAN::Reporter::Config::_get_config_file() ) {
+        my $config_obj = CPAN::Reporter::Config::_open_config_file();
+        my $config;
+        $config = CPAN::Reporter::Config::_get_config_options( $config_obj ) 
+            if $config_obj;
 
-    $timeout ||= $config->{command_timeout}; # might still be undef
+        $timeout ||= $config->{command_timeout}; # might still be undef
+    }
 
     my ($cmd, $redirect) = _split_redirect($command);
 
@@ -164,7 +166,15 @@ HERE
         ($exit_value) = $cmd_output[-1] =~ m{exited with ([-0-9]+)};
         pop @cmd_output;
     }
-    if ( ! defined $exit_value || $exit_value == -1 ) {
+    
+    # bail out on some errors
+    if ( ! defined $exit_value ) {
+        $CPAN::Frontend->mywarn( 
+            "CPAN::Reporter: couldn't determine exit value for '$cmd'\n"
+        );
+        return;
+    }
+    elsif ( $exit_value == -1 ) {
         $CPAN::Frontend->mywarn( 
             "CPAN::Reporter: couldn't execute '$cmd'\n"
         );
@@ -369,7 +379,7 @@ END_BAD_DISTNAME
             # ignore comments
             next if substr($pattern,0,1) eq '#';
             # if it doesn't match, continue with next pattern
-            next if $dist_id !~ /$pattern/;
+            next if $dist_id !~ /$pattern/i;
             # if it matches, warn and return
             $CPAN::Frontend->myprint( << "END_SKIP_DIST" );
 CPAN::Reporter: '$dist_id' matched against the send_skipfile.  
@@ -407,14 +417,15 @@ DUPLICATE_REPORT
     # Set debug and transport options, if supported
     $tr->debug( $config->{debug} ) if defined $config->{debug};
     my $transport = $config->{transport} || 'Net::SMTP';
-    if (length $transport && ( $transport !~ /\ANet::SMTP|Mail::Send\z/ )) {
+    my @transport_args = split " ", $transport;
+    eval { $tr->transport( @transport_args ) };
+    if ($@) {
         $CPAN::Frontend->mywarn(
-            "CPAN::Reporter: '$config->{transport}' is not a valid transport option." .
-            " Falling back to Net::SMTP\n"
+            "CPAN::Reporter: '$transport' is not a valid transport option.\n" .
+            "Test report will not be sent\n"
         );
-        $transport = 'Net::SMTP';
+        return;
     }
-    $tr->transport( $transport );
 
     # prepare mail transport
     $tr->from( $config->{email_from} );
@@ -472,7 +483,8 @@ sub _downgrade_known_causes {
     my $msg = $result->{grade_msg} || q{};
 
     # shortcut unless fail/unknown; but PL might look like pass but actually
-    # have "OS Unsupported" messages
+    # have "OS Unsupported" messages if someone printed message and then
+    # did "exit 0"
     return if $grade eq 'na';
     return if $grade eq 'pass' && $result->{phase} ne 'PL';
 
@@ -513,15 +525,23 @@ sub _downgrade_known_causes {
         $msg = 'This platform is not supported';
     }
     # check the prereq report for missing or failure flag '!'
-    elsif ( $result->{prereq_pm} =~ m{n/a}ims ) {
+    elsif ( $grade ne 'pass' && $result->{prereq_pm} =~ m{n/a}ims ) {
         $grade = 'discard';
         $msg = 'Prerequisite missing';
     }
-    elsif ( $result->{prereq_pm} =~ m{^\s+!}ims ) {
+    elsif ( $grade ne 'pass' && $result->{prereq_pm} =~ m{^\s+!}ims ) {
         $grade = 'discard';
         $msg = 'Prerequisite version too low';
     }
-
+    # in PL stage -- if pass but no Makefile or Build, then this should 
+    # be recorded as a discard
+    elsif ( $result->{phase} eq 'PL' && $grade eq 'pass' 
+         && ! -f 'Makefile' && ! -f 'Build' 
+    ) {
+        $grade = 'discard';
+        $msg = 'No Makefile or Build file found';
+    }
+    
     # store results
     $result->{grade} = $grade;
     $result->{grade_msg} = $msg;
@@ -584,7 +604,9 @@ sub _env_report {
 
     my $report = "";
     for my $var ( sort @vars_found ) {
-        $report .= "    $var = $ENV{$var}\n";
+        my $value = $ENV{$var};
+        $value = '[undef]' if ! defined $value;
+        $report .= "    $var = $value\n";
     }
     return $report;
 }
@@ -622,8 +644,18 @@ sub _init_result {
     my ($phase, $dist, $system_command, $output, $exit_value) = @_;
     
     unless ( defined $output && defined $exit_value ) {
+        my $missing;
+        if ( ! defined $output && ! defined $exit_value ) {
+            $missing = "exit value and output"
+        }
+        elsif ( defined $output && !defined $exit_value ) {
+            $missing =  "exit value"
+        }
+        else {
+            $missing = "output";
+        }
         $CPAN::Frontend->mywarn(
-            "CPAN::Reporter: had errors capturing output. Tests abandoned"
+            "CPAN::Reporter: had errors capturing $missing. Tests abandoned"
         );
         return;
     }
@@ -658,7 +690,7 @@ sub _init_result {
 
 sub _is_make {
     my $command = shift;
-    return $command =~ m{^\S*make|Makefile.PL$}ims ? 1 : 0;
+    return $command =~ m{\b(?:\S*make|Makefile.PL)\b}ims ? 1 : 0;
 }
 
 #--------------------------------------------------------------------------#
@@ -859,27 +891,36 @@ All tests were successful.
 HERE
 
     'fail' => <<'HERE',
-Thank you for uploading your work to CPAN.  However, it appears that
-there were some problems with your distribution.  If these results are 
-not what you expect or if you would like to learn how to avoid FAIL 
-reports for missing dependencies, unsupported operating systems, etc.,
-please consult "Notes for CPAN Authors" on the CPAN Testers Wiki: 
-http://cpantest.grango.org
+Thank you for uploading your work to CPAN.  However, there was a problem
+testing your distribution.
+
+If you think this report is invalid, please consult the CPAN Testers Wiki
+for suggestions on how to avoid getting FAIL reports for missing library
+or binary dependencies, unsupported operating systems, and so on:
+
+http://cpantest.grango.org/wiki/CPANAuthorNotes
 HERE
 
     'unknown' => <<'HERE',
 Thank you for uploading your work to CPAN.  However, attempting to
-test your distribution gave an inconclusive result.  This could be because
-you did not define tests (or tests could not be found), because
-your tests were interrupted before they finished, or because
-the results of the tests could not be parsed by CPAN::Reporter.
+test your distribution gave an inconclusive result.  
+
+This could be because you did not define tests, tests could not be 
+found, because your tests were interrupted before they finished, or 
+because the results of the tests could not be parsed.  You may wish to 
+consult the CPAN Testers Wiki:
+
+http://cpantest.grango.org/wiki/CPANAuthorNotes
 HERE
 
     'na' => <<'HERE',
 Thank you for uploading your work to CPAN.  While attempting to build or test 
 this distribution, the distribution signaled that support is not available 
 either for this operating system or this version of Perl.  Nevertheless, any 
-diagnostic output produced is provided below for reference.
+diagnostic output produced is provided below for reference.  If this is not 
+what you expect, you may wish to consult the CPAN Testers Wiki:
+
+http://cpantest.grango.org/wiki/CPANAuthorNotes
 HERE
     
 );
@@ -892,18 +933,17 @@ sub _report_text {
         my $max_k = int(MAX_OUTPUT_LENGTH/1000) . "K";
         $test_log .= "\n[Output truncated after $max_k]\n\n";
     }
+    # Flag automated report
+    my $default_comment = $ENV{AUTOMATED_TESTING} 
+        ? "this report is from an automated smoke testing program\nand was not reviewed by a human for accuracy" 
+        : "none provided" ;
+        
     # generate report
     my $output = << "ENDREPORT";
 Dear $data->{author},
     
 This is a computer-generated report for $data->{dist_name}
-on $data->{perl_version}, created automatically by CPAN-Reporter-$CPAN::Reporter::VERSION 
-and sent to the CPAN Testers mailing list.  
-
-If you have received this email directly, it is because the person testing 
-your distribution chose to send a copy to your CPAN email address; there 
-may be a delay before the official report is received and processed 
-by CPAN Testers.
+on perl $data->{perl_version}, created by CPAN-Reporter-$CPAN::Reporter::VERSION\. 
 
 $intro_para{ $data->{grade} }
 Sections of this report:
@@ -919,7 +959,7 @@ TESTER COMMENTS
 
 Additional comments from tester: 
 
-[none provided]
+$default_comment
 
 ------------------------------
 PROGRAM OUTPUT
@@ -979,7 +1019,7 @@ sub _should_copy_author {
             # ignore comments
             next if substr($pattern,0,1) eq '#';
             # if it doesn't match, continue with next pattern
-            next if $dist_id !~ /$pattern/;
+            next if $dist_id !~ /$pattern/i;
             # if it matches, warn and return
             $CPAN::Frontend->myprint( << "END_SKIP_DIST" );
 CPAN::Reporter: '$dist_id' matched against the cc_skipfile.  Won't copy author.
@@ -1016,6 +1056,7 @@ HERE
         my $getosversion = join(", ", @getosversion);
         $special_vars .= "    Win32::GetOSName = " . Win32::GetOSName() . "\n";
         $special_vars .= "    Win32::GetOSVersion = $getosversion\n";
+        $special_vars .= "    Win32::FsType = " . Win32::FsType() . "\n";
         $special_vars .= "    Win32::IsAdminUser = " . Win32::IsAdminUser() . "\n";
     }
     return $special_vars;
@@ -1106,10 +1147,12 @@ HERE
 sub _timeout_wrapper_win32 {
     my ($cmd, $timeout) = @_;
 
-    eval "use Win32::Process 0.10 ();";
+    $timeout ||= 0;  # just in case upstream doesn't guarantee it
+
+    eval "use Win32::Job ();";
     if ($@) {
         $CPAN::Frontend->mywarn( << 'HERE' );
-CPAN::Reporter: you need Win32::Process 0.10 for inactivity_timeout support.
+CPAN::Reporter: you need Win32::Job for inactivity_timeout support.
 Continuing without timeout...
 HERE
         return;
@@ -1133,25 +1176,25 @@ HERE
     # protect shell quotes and other things
     $_ = quotemeta($_) for ($program, $cmd);
 
-    my $wrapper = sprintf << 'HERE', $program, $cmd, $cmd, $timeout, $cmd;
+    my $wrapper = sprintf << 'HERE', $program, $cmd, $timeout;
 use strict;
-use Win32::Process qw/STILL_ACTIVE NORMAL_PRIORITY_CLASS/;
-my ($process,$exitcode);
-Win32::Process::Create(
-    $process,
-    "%s",
-    "%s",
-    0,
-    NORMAL_PRIORITY_CLASS,
-    "."
-) or die "Could not spawn %s: $^E\n";
-$process->Wait(%s * 1000);
-$process->GetExitCode($exitcode);
-if ($exitcode == STILL_ACTIVE) {
-    $process->Kill(9);
-    $exitcode = 9;
+use Win32::Job;
+my $executable = "%s";
+my $cmd_line = "%s";
+my $timeout = %s;
+
+my $job = Win32::Job->new() or die $^E;
+my $ppid = $job->spawn($executable, $cmd_line);
+$job->run($timeout);
+my $status = $job->status;
+my $exitcode = $status->{$ppid}{exitcode};
+if ( $exitcode == 293 ) {
+    $exitcode = 9; # map Win32::Job kill (293) to SIGKILL (9)
 }
-print "(%s exited with $exitcode)\n";
+elsif ( $exitcode & 255 ) {
+    $exitcode = $exitcode << 8; # how perl expects it
+}
+print "($cmd_line exited with $exitcode)\n";
 HERE
     return $wrapper;
 }
@@ -1241,7 +1284,15 @@ sub _version_finder {
 
     my %result;
     for my $line ( split "\n", $prereq_result ) {
+        next unless length $line;
         my ($mod, $met, $have) = split " ", $line;
+        unless ( defined($mod) && defined($met) && defined($have) ) {
+            $CPAN::Frontend->mywarn(
+                "Error parsing output from CPAN::Reporter::PrereqCheck:\n" .
+                $line
+            );
+            next;
+        }
         $result{$mod}{have} = $have;
         $result{$mod}{met} = $met;
     }
